@@ -1,7 +1,7 @@
 package WWW::PAUSE::Simple;
 
-our $DATE = '2015-04-15'; # DATE
-our $VERSION = '0.21'; # VERSION
+our $DATE = '2015-06-14'; # DATE
+our $VERSION = '0.22'; # VERSION
 
 use 5.010001;
 use strict;
@@ -123,6 +123,18 @@ $SPEC{upload_file} = {
             schema  => 'str*',
             default => '',
         },
+        delay => {
+            summary => 'Pause a number of seconds between files',
+            schema => ['int*', min=>0],
+            description => <<'_',
+
+If you upload a lot of files (e.g. 7-10 or more) at a time, the PAUSE indexer
+currently might choke with SQLite database locking problem and thus fail to
+index your releases. Giving a delay of say 2-3 minutes (120-180 seconds) between
+files will alleviate this problem.
+
+_
+        },
     },
 };
 sub upload_file {
@@ -135,6 +147,7 @@ sub upload_file {
 
     my $envres = envresmulti();
 
+    my $i = 0;
     for my $file (@$files) {
         my $res;
         {
@@ -178,6 +191,11 @@ sub upload_file {
         $res->[3]{item_id} = $file;
         $log->tracef("Result of upload: %s", $res);
         $envres->add_result($res->[0], $res->[1], $res->[3]);
+
+        if ($args{delay} && ++$i < @$files) {
+            $log->tracef("Sleeping between flies for %d second(s) ...", $args{delay});
+            sleep $args{delay};
+        }
     }
     $envres->as_struct;
 }
@@ -607,7 +625,7 @@ WWW::PAUSE::Simple - An API for PAUSE
 
 =head1 VERSION
 
-This document describes version 0.21 of WWW::PAUSE::Simple (from Perl distribution WWW-PAUSE-Simple), released on 2015-04-15.
+This document describes version 0.22 of WWW::PAUSE::Simple (from Perl distribution WWW-PAUSE-Simple), released on 2015-06-14.
 
 =head1 SYNOPSIS
 
@@ -986,6 +1004,15 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
+=item * B<delay> => I<int>
+
+Pause a number of seconds between files.
+
+If you upload a lot of files (e.g. 7-10 or more) at a time, the PAUSE indexer
+currently might choke with SQLite database locking problem and thus fail to
+index your releases. Giving a delay of say 2-3 minutes (120-180 seconds) between
+files will alleviate this problem.
+
 =item * B<files>* => I<array[str]>
 
 File names/wildcard patterns.
